Invertable Operators
====================

Demonstrates usage of the `InvertableOperator`. See the [documentation][docs]
for more information.

[docs]: https://bout-dev.readthedocs.io/en/latest/user_docs/invertable_operator.html
